@@ -32,7 +32,7 @@ from .install_magic import install_magic
 import matplotlib       # for imshow palette
 import matplotlib.cm as cm
 
-__version__ = '0.2.4'
+__version__ = '0.2.6'
 
 SIZING_METHOD = 'policies'        # or 'sizing_mode'
 
@@ -160,7 +160,7 @@ def process_max_size(kwargs, sizing_method=SIZING_METHOD):              # gridpl
     else:
         raise ValueError('Unknown sizing method. Must be either "policies" or "sizing_mode"')
 
-class BokehlabFigure(BokehFigure):
+class Figure(BokehFigure):
     __subtype__ = "BokehlabFigure"
     __view_model__ = "Plot"
     __view_module__ = "bokeh.models.plots"
@@ -218,7 +218,7 @@ class BokehlabFigure(BokehFigure):
         return bp.show(self, notebook_handle=notebook_handle)
 
 def figure(width=None, height=None, **kwargs):
-    FIGURES.append(BokehlabFigure(width=width, height=height, **kwargs))
+    FIGURES.append(Figure(width=width, height=height, **kwargs))
 
 #def Plot(*args, **kwargs):
 #    kwargs['get_p'] = True
@@ -650,8 +650,8 @@ def _plot(*args, x=None, y=None, style=None, color=None, label=None, line_width=
                     raise ValueError('datetime x values is incompatible with "%s"' % mode)
                 else:
                     figure_opts['x_axis_type'] = 'datetime'
-            p = BokehlabFigure(**figure_opts)
-            if not get_p:
+            p = Figure(**figure_opts)
+            if not (get_p or get_ps):
                 if wrap:
                     FIGURES.append((p, 'wrap'))
                 else:
@@ -899,22 +899,22 @@ def loglog(*args, **kwargs):
 #    p.yaxis.axis_label = ylabel
 
 #def hist(x, nbins=30, width=None, height=None, get_p=False, get_ws=False, p=None, hover=False, **kwargs):
-def hist(x, bins=30, hover=False, get_p=False, p=None, **kwargs):
-    h = Hist(x, bins, hover=hover, get_p=get_p, **kwargs)
+def hist(x, bins=30, range=None, hover=False, get_p=False, p=None, **kwargs):
+    h = Hist(x, bins, range=range, hover=hover, get_p=get_p, **kwargs)
     if get_p:
         return h.figure
 
 class Hist:
-    def __init__(self, x, bins=30, get_p=True, get_ws=False, p=None, hover=False, **kwargs):
+    def __init__(self, x, bins=30, range=None, get_p=True, get_ws=False, p=None, hover=False, **kwargs):
         if p is None:
             if not FIGURES:
                 kw = collect_figure_options(kwargs)
-                p = BokehlabFigure(**kw)
+                p = Figure(**kw)
                 if not get_p:
                     FIGURES.append(p)
             else:
                 p = FIGURES[-1] 
-        values, edges = np.histogram(x, density=True, bins=bins)
+        values, edges = np.histogram(x, density=True, bins=bins, range=range)
         for k, v in CONFIG.get('segment', {}).items():
             if k not in kwargs:
                 kwargs[k] = v
@@ -1086,7 +1086,7 @@ def imshow(*ims, p=None, palette='Viridis256', autolevels=True, show_axes=False,
         if show_toolbar:
             kw['width'] += 30
 #        kw['width'], kw['height'] = calc_size(kw['width'], kw['height'], im.shape[1], im.shape[0], toolbar)
-        p = BokehlabFigure(**kw)
+        p = Figure(**kw)
         if title_location is not None:
             p.title.align = 'center'
         if not get_p:
@@ -1322,7 +1322,7 @@ def load_ipython_extension(ip):
     if mode == 'none':
         return
     d = dict(
-        Figure=BokehlabFigure, figure=figure,
+        Figure=Figure, figure=figure,
         plot=plot, Plot=Plot, stem=stem, Stem=Stem, hist=hist, Hist=Hist,
         semilogx=semilogx, semilogy=semilogy, loglog=loglog,
         Semilogx=Semilogx, Semilogy=Semilogy, Loglog=Loglog,
